# GraphQ Trans

GraphQ Trans is a source-to-source compiler that supports the transpilation among multiple graph query languages via a unified intermediate representation. For detailed documentation, please refer to our project website https://github.com/Flitternie/graphq_trans

## Dependencies

This package relies on [ANTLR4](https://www.antlr.org/) for front-end analysis and has the following dependencies:

* Python >= 3.6.2

* ANTLR >= 4.9.2

* antlr4-python3-runtime >= 4.9.2


## Citation

If you find our work helpful, please cite it as follows:

```
@article{nie2022graphq,
  title={GraphQ IR: Unifying Semantic Parsing of Graph Query Language with Intermediate Representation},
  author={Nie, Lunyiu and Cao, Shulin and Shi, Jiaxin and Tian, Qi and Hou, Lei and Li, Juanzi and Zhai, Jidong},
  journal={arXiv preprint arXiv:2205.12078},
  year={2022}
}
```
